// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "clawsmailplugin_debug.h"


Q_LOGGING_CATEGORY(CLAWSMAILPLUGIN_LOG, "org.kde.pim.importwizard.clawsmailplugin", QtInfoMsg)

