/********************************************************************************
** Form generated from reading UI file 'manualimportmailpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANUALIMPORTMAILPAGE_H
#define UI_MANUALIMPORTMAILPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "mailimporter/importmailswidget.h"

QT_BEGIN_NAMESPACE

class Ui_ManualImportMailPage
{
public:
    QHBoxLayout *hboxLayout;
    QLabel *mIntroSidebar;
    QSpacerItem *spacer54;
    QVBoxLayout *vboxLayout;
    MailImporter::ImportMailsWidget *mMailImporterWidget;
    QLabel *textLabel1_2;

    void setupUi(QWidget *ManualImportMailPage)
    {
        if (ManualImportMailPage->objectName().isEmpty())
            ManualImportMailPage->setObjectName("ManualImportMailPage");
        ManualImportMailPage->resize(586, 452);
        hboxLayout = new QHBoxLayout(ManualImportMailPage);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        mIntroSidebar = new QLabel(ManualImportMailPage);
        mIntroSidebar->setObjectName("mIntroSidebar");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mIntroSidebar->sizePolicy().hasHeightForWidth());
        mIntroSidebar->setSizePolicy(sizePolicy);
        mIntroSidebar->setMinimumSize(QSize(170, 430));
        mIntroSidebar->setFrameShape(QFrame::StyledPanel);
        mIntroSidebar->setFrameShadow(QFrame::Plain);
        mIntroSidebar->setLineWidth(0);
        mIntroSidebar->setScaledContents(true);
        mIntroSidebar->setWordWrap(false);
        mIntroSidebar->setIndent(0);

        hboxLayout->addWidget(mIntroSidebar);

        spacer54 = new QSpacerItem(10, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacer54);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        mMailImporterWidget = new MailImporter::ImportMailsWidget(ManualImportMailPage);
        mMailImporterWidget->setObjectName("mMailImporterWidget");

        vboxLayout->addWidget(mMailImporterWidget);

        textLabel1_2 = new QLabel(ManualImportMailPage);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setWordWrap(false);

        vboxLayout->addWidget(textLabel1_2);


        hboxLayout->addLayout(vboxLayout);


        retranslateUi(ManualImportMailPage);

        QMetaObject::connectSlotsByName(ManualImportMailPage);
    } // setupUi

    void retranslateUi(QWidget *ManualImportMailPage)
    {
        textLabel1_2->setText(tr2i18n("Click 'Back' to import more emails", nullptr));
        (void)ManualImportMailPage;
    } // retranslateUi

};

namespace Ui {
    class ManualImportMailPage: public Ui_ManualImportMailPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANUALIMPORTMAILPAGE_H

