/********************************************************************************
** Form generated from reading UI file 'manualselectfilterpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANUALSELECTFILTERPAGE_H
#define UI_MANUALSELECTFILTERPAGE_H

#include <MailCommon/FolderRequester>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ManualSelectFilterPage
{
public:
    QHBoxLayout *hboxLayout;
    QLabel *mIntroSidebar;
    QSpacerItem *spacer56;
    QVBoxLayout *_2;
    QLabel *TextLabel6;
    QComboBox *mFilterCombo;
    QTextEdit *mDesc;
    QLabel *label;
    MailCommon::FolderRequester *mCollectionRequestor;
    QCheckBox *remDupMsg;

    void setupUi(QWidget *ManualSelectFilterPage)
    {
        if (ManualSelectFilterPage->objectName().isEmpty())
            ManualSelectFilterPage->setObjectName("ManualSelectFilterPage");
        ManualSelectFilterPage->resize(606, 461);
        hboxLayout = new QHBoxLayout(ManualSelectFilterPage);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        mIntroSidebar = new QLabel(ManualSelectFilterPage);
        mIntroSidebar->setObjectName("mIntroSidebar");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mIntroSidebar->sizePolicy().hasHeightForWidth());
        mIntroSidebar->setSizePolicy(sizePolicy);
        mIntroSidebar->setMinimumSize(QSize(170, 430));
        mIntroSidebar->setFrameShape(QFrame::StyledPanel);
        mIntroSidebar->setFrameShadow(QFrame::Plain);
        mIntroSidebar->setLineWidth(0);
        mIntroSidebar->setScaledContents(true);
        mIntroSidebar->setWordWrap(false);
        mIntroSidebar->setIndent(0);

        hboxLayout->addWidget(mIntroSidebar);

        spacer56 = new QSpacerItem(10, 10, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacer56);

        _2 = new QVBoxLayout();
        _2->setObjectName("_2");
        _2->setContentsMargins(0, 0, 0, 0);
        TextLabel6 = new QLabel(ManualSelectFilterPage);
        TextLabel6->setObjectName("TextLabel6");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(TextLabel6->sizePolicy().hasHeightForWidth());
        TextLabel6->setSizePolicy(sizePolicy1);
        TextLabel6->setTextFormat(Qt::RichText);
        TextLabel6->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        TextLabel6->setWordWrap(true);

        _2->addWidget(TextLabel6);

        mFilterCombo = new QComboBox(ManualSelectFilterPage);
        mFilterCombo->setObjectName("mFilterCombo");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(mFilterCombo->sizePolicy().hasHeightForWidth());
        mFilterCombo->setSizePolicy(sizePolicy2);

        _2->addWidget(mFilterCombo);

        mDesc = new QTextEdit(ManualSelectFilterPage);
        mDesc->setObjectName("mDesc");
        mDesc->setReadOnly(true);

        _2->addWidget(mDesc);

        label = new QLabel(ManualSelectFilterPage);
        label->setObjectName("label");

        _2->addWidget(label);

        mCollectionRequestor = new MailCommon::FolderRequester(ManualSelectFilterPage);
        mCollectionRequestor->setObjectName("mCollectionRequestor");

        _2->addWidget(mCollectionRequestor);

        remDupMsg = new QCheckBox(ManualSelectFilterPage);
        remDupMsg->setObjectName("remDupMsg");
        remDupMsg->setChecked(false);

        _2->addWidget(remDupMsg);


        hboxLayout->addLayout(_2);


        retranslateUi(ManualSelectFilterPage);

        QMetaObject::connectSlotsByName(ManualSelectFilterPage);
    } // setupUi

    void retranslateUi(QWidget *ManualSelectFilterPage)
    {
        TextLabel6->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'DejaVu Sans'; font-size:9pt; font-weight:600;\">Welcome to ImportWizard The Mail Import Tool</span><span style=\" font-family:'DejaVu Sans'; font-size:9pt;\"> <br /><br />This program will help you import your email from your previous email program.<br /><br />Please select the program you would like to import from. Next, select the folder you would like to import to, then click 'Next'.</span></p></body></html>", nullptr));
        label->setText(tr2i18n("Please select the folder to import to:", nullptr));
        remDupMsg->setText(tr2i18n("Remove &duplicate messages during import", nullptr));
        (void)ManualSelectFilterPage;
    } // retranslateUi

};

namespace Ui {
    class ManualSelectFilterPage: public Ui_ManualSelectFilterPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANUALSELECTFILTERPAGE_H

