/********************************************************************************
** Form generated from reading UI file 'importcalendarpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTCALENDARPAGE_H
#define UI_IMPORTCALENDARPAGE_H

#include <PimCommon/CustomLogWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImportCalendarPage
{
public:
    QVBoxLayout *verticalLayout;
    PimCommon::CustomLogWidget *logCalendar;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *importCalendar;

    void setupUi(QWidget *ImportCalendarPage)
    {
        if (ImportCalendarPage->objectName().isEmpty())
            ImportCalendarPage->setObjectName("ImportCalendarPage");
        ImportCalendarPage->resize(400, 300);
        verticalLayout = new QVBoxLayout(ImportCalendarPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        logCalendar = new PimCommon::CustomLogWidget(ImportCalendarPage);
        logCalendar->setObjectName("logCalendar");

        verticalLayout->addWidget(logCalendar);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        importCalendar = new QPushButton(ImportCalendarPage);
        importCalendar->setObjectName("importCalendar");

        horizontalLayout->addWidget(importCalendar);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(ImportCalendarPage);

        QMetaObject::connectSlotsByName(ImportCalendarPage);
    } // setupUi

    void retranslateUi(QWidget *ImportCalendarPage)
    {
        importCalendar->setText(tr2i18n("Import calendar", nullptr));
        (void)ImportCalendarPage;
    } // retranslateUi

};

namespace Ui {
    class ImportCalendarPage: public Ui_ImportCalendarPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTCALENDARPAGE_H

