/********************************************************************************
** Form generated from reading UI file 'selectcomponentpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTCOMPONENTPAGE_H
#define UI_SELECTCOMPONENTPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SelectComponentPage
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout;
    QCheckBox *mails;
    QCheckBox *filters;
    QCheckBox *settings;
    QCheckBox *addressbooks;
    QCheckBox *calendars;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;
    QLabel *label_2;
    QLabel *label;
    QCheckBox *everything;

    void setupUi(QWidget *SelectComponentPage)
    {
        if (SelectComponentPage->objectName().isEmpty())
            SelectComponentPage->setObjectName("SelectComponentPage");
        SelectComponentPage->resize(400, 300);
        gridLayout = new QGridLayout(SelectComponentPage);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        mails = new QCheckBox(SelectComponentPage);
        mails->setObjectName("mails");
        mails->setEnabled(false);

        verticalLayout->addWidget(mails);

        filters = new QCheckBox(SelectComponentPage);
        filters->setObjectName("filters");
        filters->setEnabled(false);

        verticalLayout->addWidget(filters);

        settings = new QCheckBox(SelectComponentPage);
        settings->setObjectName("settings");
        settings->setEnabled(false);

        verticalLayout->addWidget(settings);

        addressbooks = new QCheckBox(SelectComponentPage);
        addressbooks->setObjectName("addressbooks");
        addressbooks->setEnabled(false);

        verticalLayout->addWidget(addressbooks);

        calendars = new QCheckBox(SelectComponentPage);
        calendars->setObjectName("calendars");
        calendars->setEnabled(false);

        verticalLayout->addWidget(calendars);


        horizontalLayout->addLayout(verticalLayout);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 3, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 1);

        label_2 = new QLabel(SelectComponentPage);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        gridLayout->addWidget(label_2, 0, 0, 1, 2);

        label = new QLabel(SelectComponentPage);
        label->setObjectName("label");

        gridLayout->addWidget(label, 2, 0, 1, 1);

        everything = new QCheckBox(SelectComponentPage);
        everything->setObjectName("everything");
        everything->setChecked(true);

        gridLayout->addWidget(everything, 1, 0, 1, 1);

        everything->raise();
        label->raise();
        label_2->raise();

        retranslateUi(SelectComponentPage);

        QMetaObject::connectSlotsByName(SelectComponentPage);
    } // setupUi

    void retranslateUi(QWidget *SelectComponentPage)
    {
        mails->setText(tr2i18n("Mails", nullptr));
        filters->setText(tr2i18n("Filters", nullptr));
        settings->setText(tr2i18n("Settings", nullptr));
        addressbooks->setText(tr2i18n("Address Books", nullptr));
        calendars->setText(tr2i18n("Calendars", nullptr));
        label_2->setText(tr2i18n("This wizard will import mail messages, addressbook entries, filters and/or settings from other mail programs into KMail", nullptr));
        label->setText(tr2i18n("Or select types of material to import:", nullptr));
        everything->setText(tr2i18n("Import Everything", nullptr));
        (void)SelectComponentPage;
    } // retranslateUi

};

namespace Ui {
    class SelectComponentPage: public Ui_SelectComponentPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTCOMPONENTPAGE_H

