/********************************************************************************
** Form generated from reading UI file 'importmailpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTMAILPAGE_H
#define UI_IMPORTMAILPAGE_H

#include <MailCommon/FolderRequester>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "mailimporter/importmailswidget.h"

QT_BEGIN_NAMESPACE

class Ui_ImportMailPage
{
public:
    QVBoxLayout *verticalLayout;
    MailImporter::ImportMailsWidget *mMailImporterWidget;
    QLabel *label;
    MailCommon::FolderRequester *mCollectionRequestor;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *importMails;

    void setupUi(QWidget *ImportMailPage)
    {
        if (ImportMailPage->objectName().isEmpty())
            ImportMailPage->setObjectName("ImportMailPage");
        ImportMailPage->resize(400, 300);
        verticalLayout = new QVBoxLayout(ImportMailPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        mMailImporterWidget = new MailImporter::ImportMailsWidget(ImportMailPage);
        mMailImporterWidget->setObjectName("mMailImporterWidget");

        verticalLayout->addWidget(mMailImporterWidget);

        label = new QLabel(ImportMailPage);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        mCollectionRequestor = new MailCommon::FolderRequester(ImportMailPage);
        mCollectionRequestor->setObjectName("mCollectionRequestor");

        verticalLayout->addWidget(mCollectionRequestor);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        importMails = new QPushButton(ImportMailPage);
        importMails->setObjectName("importMails");
        importMails->setEnabled(false);

        horizontalLayout->addWidget(importMails);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(ImportMailPage);

        QMetaObject::connectSlotsByName(ImportMailPage);
    } // setupUi

    void retranslateUi(QWidget *ImportMailPage)
    {
        label->setText(tr2i18n("Please select the folder to import to:", nullptr));
        importMails->setText(tr2i18n("Import Mails", nullptr));
        (void)ImportMailPage;
    } // retranslateUi

};

namespace Ui {
    class ImportMailPage: public Ui_ImportMailPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTMAILPAGE_H

