// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "sylpheedplugin_debug.h"


Q_LOGGING_CATEGORY(SYLPHEEDPLUGIN_LOG, "org.kde.pim.importwizard.sylpheedplugin", QtInfoMsg)

