/********************************************************************************
** Form generated from reading UI file 'importfinishpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTFINISHPAGE_H
#define UI_IMPORTFINISHPAGE_H

#include <PimCommon/CustomLogWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImportFinishPage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    PimCommon::CustomLogWidget *logFinish;

    void setupUi(QWidget *ImportFinishPage)
    {
        if (ImportFinishPage->objectName().isEmpty())
            ImportFinishPage->setObjectName("ImportFinishPage");
        ImportFinishPage->resize(400, 300);
        verticalLayout = new QVBoxLayout(ImportFinishPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(ImportFinishPage);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        logFinish = new PimCommon::CustomLogWidget(ImportFinishPage);
        logFinish->setObjectName("logFinish");

        verticalLayout->addWidget(logFinish);


        retranslateUi(ImportFinishPage);

        QMetaObject::connectSlotsByName(ImportFinishPage);
    } // setupUi

    void retranslateUi(QWidget *ImportFinishPage)
    {
        label->setText(tr2i18n("Summary:", nullptr));
        (void)ImportFinishPage;
    } // retranslateUi

};

namespace Ui {
    class ImportFinishPage: public Ui_ImportFinishPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTFINISHPAGE_H

