/********************************************************************************
** Form generated from reading UI file 'selectprogrampage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTPROGRAMPAGE_H
#define UI_SELECTPROGRAMPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "autodetect/widgets/selectprogramlistwidget.h"

QT_BEGIN_NAMESPACE

class Ui_SelectProgramPage
{
public:
    QVBoxLayout *verticalLayout;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    SelectProgramListWidget *listProgramFound;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_5;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_2;
    QSpacerItem *verticalSpacer;
    QCheckBox *manualSelectionCheckBox;

    void setupUi(QWidget *SelectProgramPage)
    {
        if (SelectProgramPage->objectName().isEmpty())
            SelectProgramPage->setObjectName("SelectProgramPage");
        SelectProgramPage->resize(400, 300);
        verticalLayout = new QVBoxLayout(SelectProgramPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        stackedWidget = new QStackedWidget(SelectProgramPage);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        verticalLayout_3 = new QVBoxLayout(page);
        verticalLayout_3->setSpacing(0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(page);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        listProgramFound = new SelectProgramListWidget(page);
        listProgramFound->setObjectName("listProgramFound");

        verticalLayout_2->addWidget(listProgramFound);


        verticalLayout_3->addLayout(verticalLayout_2);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        verticalLayout_5 = new QVBoxLayout(page_2);
        verticalLayout_5->setSpacing(0);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        label_2 = new QLabel(page_2);
        label_2->setObjectName("label_2");

        verticalLayout_4->addWidget(label_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);


        verticalLayout_5->addLayout(verticalLayout_4);

        stackedWidget->addWidget(page_2);

        verticalLayout->addWidget(stackedWidget);

        manualSelectionCheckBox = new QCheckBox(SelectProgramPage);
        manualSelectionCheckBox->setObjectName("manualSelectionCheckBox");

        verticalLayout->addWidget(manualSelectionCheckBox);


        retranslateUi(SelectProgramPage);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SelectProgramPage);
    } // setupUi

    void retranslateUi(QWidget *SelectProgramPage)
    {
        label->setText(tr2i18n("Please select the program from which you like to import:", nullptr));
        label_2->setText(tr2i18n("No program found", nullptr));
        manualSelectionCheckBox->setText(tr2i18n("Manual Selection", nullptr));
        (void)SelectProgramPage;
    } // retranslateUi

};

namespace Ui {
    class SelectProgramPage: public Ui_SelectProgramPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTPROGRAMPAGE_H

