/********************************************************************************
** Form generated from reading UI file 'importsettingpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTSETTINGPAGE_H
#define UI_IMPORTSETTINGPAGE_H

#include <PimCommon/CustomLogWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImportSettingPage
{
public:
    QVBoxLayout *verticalLayout;
    PimCommon::CustomLogWidget *logSettings;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *importSettings;

    void setupUi(QWidget *ImportSettingPage)
    {
        if (ImportSettingPage->objectName().isEmpty())
            ImportSettingPage->setObjectName("ImportSettingPage");
        ImportSettingPage->resize(400, 300);
        verticalLayout = new QVBoxLayout(ImportSettingPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        logSettings = new PimCommon::CustomLogWidget(ImportSettingPage);
        logSettings->setObjectName("logSettings");

        verticalLayout->addWidget(logSettings);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        importSettings = new QPushButton(ImportSettingPage);
        importSettings->setObjectName("importSettings");

        horizontalLayout->addWidget(importSettings);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(ImportSettingPage);

        QMetaObject::connectSlotsByName(ImportSettingPage);
    } // setupUi

    void retranslateUi(QWidget *ImportSettingPage)
    {
        importSettings->setText(tr2i18n("Import settings", nullptr));
        (void)ImportSettingPage;
    } // retranslateUi

};

namespace Ui {
    class ImportSettingPage: public Ui_ImportSettingPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTSETTINGPAGE_H

