/********************************************************************************
** Form generated from reading UI file 'importfilterpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTFILTERPAGE_H
#define UI_IMPORTFILTERPAGE_H

#include <PimCommon/CustomLogWidget>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ImportFilterPage
{
public:
    QVBoxLayout *verticalLayout;
    PimCommon::CustomLogWidget *logFilters;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *importFilters;

    void setupUi(QWidget *ImportFilterPage)
    {
        if (ImportFilterPage->objectName().isEmpty())
            ImportFilterPage->setObjectName("ImportFilterPage");
        ImportFilterPage->resize(400, 300);
        verticalLayout = new QVBoxLayout(ImportFilterPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        logFilters = new PimCommon::CustomLogWidget(ImportFilterPage);
        logFilters->setObjectName("logFilters");

        verticalLayout->addWidget(logFilters);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        importFilters = new QPushButton(ImportFilterPage);
        importFilters->setObjectName("importFilters");

        horizontalLayout->addWidget(importFilters);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(ImportFilterPage);

        QMetaObject::connectSlotsByName(ImportFilterPage);
    } // setupUi

    void retranslateUi(QWidget *ImportFilterPage)
    {
        importFilters->setText(tr2i18n("Import Filters", nullptr));
        (void)ImportFilterPage;
    } // retranslateUi

};

namespace Ui {
    class ImportFilterPage: public Ui_ImportFilterPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTFILTERPAGE_H

